
\mainpage Ts: Time Splines

# Ts Library

**The Ts library is IN DEVELOPMENT.**  It is not yet ready for general use.
Please see the [Project Status](@ref page_ts_status) document.

Ts implements the _time spline_: an artist-friendly mathematical representation
of a value that varies over time, usually continuously.

The most important classes are \ref TsSpline, \ref TsKnot, and \ref TsKnotMap.

# Subtopics

[Regressive Splines](@ref page_ts_regression)

[The TsTest Framework](@ref page_ts_tsTest)
